VimeoNoStreamException class

The video resolved, but Vimeo exposed no stream this package can play.

Inheritance

Constructors

VimeoNoStreamException(String videoId)
Creates a no-stream error for videoId.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
A short, user-presentable description of what went wrong.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
videoId String
The video id that produced no playable stream.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited