VimeoOwner class

The Vimeo account that published a video.

Constructors

VimeoOwner({int? id, String? name, String? avatarUrl})
Creates an owner descriptor.
const

Properties

avatarUrl String?
Profile picture URL, if the account has one.
final
hashCode int
The hash code for this object.
no setterinherited
id int?
Vimeo's numeric account id.
final
name String?
Display name, e.g. Courtney Karwal.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited